#
# spec file for package yast2-schema-micro
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-schema-micro
Version:        4.6.3
Release:        150600.1.2

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# source to generate rpm is same as with default, just limited set of build depedencies
# results in limited profile
Source0:        yast2-schema-default-%{version}.tar.bz2

URL:            https://github.com/yast/yast-schema

# provide schema, so it is full replacement
Provides:       yast2-schema = %{version}
# others cannot be used as it contains same files
Conflicts:      yast2-schema
Obsoletes:      yast2-schema < 4.4.9

# Dependencies needed to build the package
BuildRequires:  jing
BuildRequires:  libxml2-tools
BuildRequires:  trang
BuildRequires:  yast2-devtools

# LUKS-related elements in the partitioning schema
BuildRequires:  autoyast2 >= 4.6.4
BuildRequires:  yast2
BuildRequires:  yast2-add-on >= 4.3.3
# set 't' element in 'initrd_module' element
BuildRequires:  yast2-bootloader >= 4.3.12
BuildRequires:  yast2-configuration-management >= 4.3.0
BuildRequires:  yast2-country >= 4.3.0
# add 'iface' element
BuildRequires:  yast2-iscsi-client >= 4.3.3
# Added fcoe-client schema
BuildRequires:  yast2-fcoe-client >= 4.3.1
BuildRequires:  yast2-kdump >= 4.6.2
# add route 'extrapara' element
BuildRequires:  yast2-network >= 4.5.4
# registration is available only where suse connect is also available
%ifnarch s390 %ix86
# addons: architecture/version is optional
BuildRequires:  yast2-registration >= 4.3.12
%endif
# Add support for security policies ('security_policy')
BuildRequires:  yast2-security >= 4.5.3
BuildRequires:  yast2-services-manager
# tag home_btrfs_subvolume
BuildRequires:  yast2-users >= 4.1.11

#!BuildIgnore: yast2-build-test

# optimization suggested by AJ:
#!BuildIgnore: tomcat5

# ignoring conflicting packages
#!BuildIgnore: yast2-branding-SLED yast2-branding-openSUSE
#!BuildIgnore: yast2-theme yast2-theme-SLED yast2-theme-openSUSE yast2-theme-SLE

# Hotfix to build a package, bnc #427684
#!BuildIgnore: xerces-j2-bootstrap libusb-0_1-4 crimson

# To speedup && to easily recover from dependency hell
#!BuildIgnore: yast2-pkg-bindings zypper libzypp yast2-gtk yast2-qt yast2-ncurses yast2-qt-pkg yast2-ncurses-pkg

# Yast packages without AutoYast support
#!BuildIgnore: yast2-country-data
#!BuildIgnore: yast2-control-center yast2-control-center-gnome yast2-control-center-qt

Summary:        YaST2 - AutoYaST Schema for Micro
License:        GPL-2.0-or-later
Group:          System/YaST

%description
AutoYaST Syntax Schema for Micro product

%prep
%setup -n yast2-schema-default-%{version}

%build
%yast_build

%install
%yast_install
rm -rf %{buildroot}/%{_docdir}/yast2-schema-default

%files
%defattr(-,root,root)
%dir %{yast_schemadir}/autoyast/rnc
%{yast_schemadir}/autoyast/rnc/profile.rnc
%{yast_schemadir}/autoyast/rnc/includes.rnc
%dir %{yast_schemadir}/autoyast/rng
%{yast_schemadir}/autoyast/rng/*.rng

%changelog
* Mon Nov 13 2023 jreidinger@suse.com
- One more bump to use really the proper SP6 version of yast2-kdump
  (bsc#1217057)
- 4.6.3
* Fri Nov 10 2023 jreidinger@suse.com
- Bump schema to adapt for version kdump versions 1.9+ (bsc#1212646)
- 4.6.2
* Fri Sep 22 2023 ancor@suse.com
- Added several LUKS-related elements to the partitioning schema
  (jsc#PED-3878, jsc#PED-5518).
- 4.6.1
* Fri Sep  1 2023 jreidinger@suse.com
- Branch package for SP6 (bsc#1208913)
* Tue Feb  7 2023 jreidinger@suse.com
- drop yast2-dhcp-server and yast2-http-server schema from TW as
  it also depends on yast2-dns-server (bsc#1205363)
- 4.5.9
* Mon Feb  6 2023 jreidinger@suse.com
- drop yast2-dns-server schema from TW (bsc#1205363)
- 4.5.8
* Mon Jan 23 2023 jreidinger@suse.com
- drop yast2-sound schema spec from TW where yast2-sound is dropped
  (bsc#1206903)
- 4.5.7
* Thu Nov  3 2022 igonzalezsosa@suse.com
- Add support for security policies validation (jsc#SLE-24764).
- Synchronize SP4 and master branches (related to bsc#1199165).
- 4.5.6
* Fri Aug 12 2022 dgonzalez@suse.com
- Add KDUMP_AUTO_RESIZE element in kdump section
  (related to jsc#SLE-18441 and gh#yast/yast-kdump#123).
- 4.5.5
* Mon Jul  4 2022 kanderssen@suse.com
- Add 'extrapara' to routes in the networking section (bsc#1201129)
- 4.5.4
* Thu May 26 2022 igonzalezsosa@suse.com
- Support for flatten and nested "category_filter" element in the
  "online_update_configuration" section (bsc#1198848).
- 4.5.3
* Mon Apr 11 2022 lslezak@suse.cz
- Fix up for the previous change (related to bsc#1183893)
- 4.5.2
* Fri Apr  8 2022 jlopez@suse.com
- Remove dependency of YaST NIS packages from TW (bsc#1183893).
- 4.5.1
* Wed Apr  6 2022 lslezak@suse.cz
- Bump version to 4.5.0 (bsc#1198109)
* Fri Feb 18 2022 kanderssen@suse.com
- Added fcoe-client schema (bsc#1194895)
- 4.4.11
* Wed Jan 26 2022 kanderssen@suse.com
- Synced version with default schema (related to jsc#SLE-22069).
- 4.4.10
* Fri Jan 21 2022 jreidinger@suse.com
- Adapt dependencies for SLE15 SP3 as micro is based on it
* Wed Jan 19 2022 jreidinger@suse.com
- initial package to have dedicated limited schema for Micro
  product (jsc#SLE-18820)
- 4.4.9
